---
title: <span class="badge object-type-scalar"></span> NanogramPerNormalCubicMeter
---
# <span class="badge object-type-scalar"></span> NanogramPerNormalCubicMeter

Concentration: nanogram per normal cubic meter (ng/Nm³)

## Definition

```python
# Concentration: nanogram per normal cubic meter (ng/Nm³)
NanogramPerNormalCubicMeter: typing.Literal["conngNm3"] = "conngNm3"
```
